# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_HIST_METADATA = Metadata(
    id="5dff8f7ac913ce4a3781c6d59d7827316323eded.boutiques",
    name="3dHist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dHistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_hist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_hist(
    input_: InputPathType,
    mask_dset: InputPathType | None = None,
    mask_range: list[float] | None = None,
    cmask: str | None = None,
    hist_file: InputPathType | None = None,
    prefix: str | None = None,
    equalized: str | None = None,
    nbin: float | None = None,
    min_: float | None = None,
    max_: float | None = None,
    binwidth: float | None = None,
    ignore_out: bool = False,
    range_hist: InputPathType | None = None,
    showhist: bool = False,
    at_val: float | None = None,
    get_params: str | None = None,
    voxvol: float | None = None,
    val_at: str | None = None,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dHistOutputs:
    """
    Computes histograms using functions for generating priors.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Dataset providing values for histogram.
        mask_dset: Provide mask dataset to select subset of input.
        mask_range: Specify the range of values to consider from MSET. Default\
            is anything non-zero.
        cmask: Provide cmask expression. Voxels where expression is 0 are\
            excluded from computations.
        hist_file: Read this previously created histogram instead of forming\
            one from DSET.
        prefix: Write histogram to niml file called PREF.niml.hist.
        equalized: Write a histogram equalized version of the input dataset.
        nbin: Use K bins.
        min_: Minimum intensity.
        max_: Maximum intensity.
        binwidth: Bin width.
        ignore_out: Do not count samples outside the user specified range.
        range_hist: Use previously created histogram to set range and binwidth\
            parameters.
        showhist: Display histogram to stdout.
        at_val: Set the value at which you want histogram values.
        get_params: Return the desired properties at a given value. You can\
            select multiple properties.
        voxvol: Specify voxel volume in mm^3. To be used with upvol.
        val_at: Return the value where histogram property PAR is equal to\
            PARVAL. PAR can be: cdf, rcdf, ncdf, nrcdf, upvol.
        quiet: Return a concise output to simplify parsing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dHistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_HIST_METADATA)
    cargs = []
    cargs.append("3dHist")
    cargs.append(execution.input_file(input_))
    if mask_dset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dset)
        ])
    if mask_range is not None:
        cargs.extend([
            "-mask_range",
            *map(str, mask_range)
        ])
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    if hist_file is not None:
        cargs.extend([
            "-thishist",
            execution.input_file(hist_file)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if equalized is not None:
        cargs.extend([
            "-equalized",
            equalized
        ])
    if nbin is not None:
        cargs.extend([
            "-nbin",
            str(nbin)
        ])
    if min_ is not None:
        cargs.extend([
            "-min",
            str(min_)
        ])
    if max_ is not None:
        cargs.extend([
            "-max",
            str(max_)
        ])
    if binwidth is not None:
        cargs.extend([
            "-binwidth",
            str(binwidth)
        ])
    if ignore_out:
        cargs.append("-ignore_out")
    if range_hist is not None:
        cargs.extend([
            "-rhist",
            execution.input_file(range_hist)
        ])
    if showhist:
        cargs.append("-showhist")
    if at_val is not None:
        cargs.extend([
            "-at",
            str(at_val)
        ])
    if get_params is not None:
        cargs.extend([
            "-get",
            get_params
        ])
    if voxvol is not None:
        cargs.extend([
            "-voxvol",
            str(voxvol)
        ])
    if val_at is not None:
        cargs.extend([
            "-val_at",
            val_at
        ])
    if quiet:
        cargs.append("-quiet")
    ret = V3dHistOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dHistOutputs",
    "V_3D_HIST_METADATA",
    "v_3d_hist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENA_DIFF_METADATA = Metadata(
    id="e8aca2fd67e31bd3e2c0994ac03b8c6a57e6de78.boutiques",
    name="siena_diff",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SienaDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `siena_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def siena_diff(
    input1_basename: str,
    input2_basename: str,
    debug_flag: bool = False,
    no_seg_flag: bool = False,
    self_corr_factor: float | None = None,
    ignore_z_flow_flag: bool = False,
    apply_std_mask_flag: bool = False,
    segment_options: str | None = None,
    runner: Runner | None = None,
) -> SienaDiffOutputs:
    """
    SIENA_diff: Analysis of longitudinal brain image differences.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input1_basename: Input image 1 basename.
        input2_basename: Input image 2 basename.
        debug_flag: Debug - generate edge images and don't remove temporary\
            images.
        no_seg_flag: Don't segment grey+white separately (because there is poor\
            grey-white contrast).
        self_corr_factor: Apply self-calibrating correction factor.
        ignore_z_flow_flag: Ignore flow in z (may be beneficial if top of brain\
            is missing).
        apply_std_mask_flag: Apply <input1_basename>_stdmask to brain edge\
            points.
        segment_options: Options to be passed to segmentation (type 'fast' to\
            get these).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENA_DIFF_METADATA)
    cargs = []
    cargs.append("siena_diff")
    cargs.append(input1_basename)
    cargs.append(input2_basename)
    if debug_flag:
        cargs.append("-d")
    if no_seg_flag:
        cargs.append("-2")
    if self_corr_factor is not None:
        cargs.extend([
            "-c",
            str(self_corr_factor)
        ])
    if ignore_z_flow_flag:
        cargs.append("-i")
    if apply_std_mask_flag:
        cargs.append("-m")
    if segment_options is not None:
        cargs.extend([
            "-s",
            segment_options
        ])
    ret = SienaDiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENA_DIFF_METADATA",
    "SienaDiffOutputs",
    "siena_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_THRESHOLD_METADATA = Metadata(
    id="18dd783d6c61c6360f3439c48e74d88d1a862887.boutiques",
    name="mri_threshold",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriThresholdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_threshold(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_vol_file: OutputPathType
    """Thresholded output volume"""


def mri_threshold(
    input_vol: InputPathType,
    threshold: float,
    output_vol: str,
    binarize: float | None = None,
    upper_threshold: bool = False,
    frame_number: float | None = None,
    runner: Runner | None = None,
) -> MriThresholdOutputs:
    """
    This program will lower threshold an input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input volume file.
        threshold: Threshold value for the volume.
        output_vol: Output volume file.
        binarize: Binarize the output volume with specified bval.
        upper_threshold: Upper threshold the volume instead of lower\
            thresholding.
        frame_number: Apply thresholding to a specific frame indexed by fnum.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriThresholdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_THRESHOLD_METADATA)
    cargs = []
    cargs.append("mri_threshold")
    cargs.append(execution.input_file(input_vol))
    cargs.append(str(threshold))
    cargs.append(output_vol)
    if binarize is not None:
        cargs.extend([
            "-B",
            str(binarize)
        ])
    if upper_threshold:
        cargs.append("-U")
    if frame_number is not None:
        cargs.extend([
            "-F",
            str(frame_number)
        ])
    ret = MriThresholdOutputs(
        root=execution.output_file("."),
        output_vol_file=execution.output_file(output_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_THRESHOLD_METADATA",
    "MriThresholdOutputs",
    "mri_threshold",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_DW_GRAD_O_MAT___METADATA = Metadata(
    id="46eee009ed5251cf0654dc7e2305bcbaecf3782b.boutiques",
    name="1dDW_Grad_o_Mat++",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dDwGradOMatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_dw_grad_o_mat__(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file of gradients or matrices"""
    out_row_bval_file: OutputPathType | None
    """Output b-values file in a single row"""
    out_col_bval_file: OutputPathType | None
    """Output b-values file in a single column"""


def v_1d_dw_grad_o_mat__(
    in_row_vec: InputPathType,
    in_col_vec: InputPathType,
    in_col_mat_a: InputPathType,
    in_col_mat_t: InputPathType,
    out_row_vec: str,
    out_col_vec: str,
    out_col_mat_a: str,
    out_col_mat_t: str,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    no_flip: bool = False,
    in_bvals: InputPathType | None = None,
    out_col_bval: bool = False,
    out_row_bval_sep: str | None = None,
    out_col_bval_sep: str | None = None,
    unit_mag_out: bool = False,
    check_abs_min: float | None = None,
    bref_mean_top: bool = False,
    put_zeros_top: bool = False,
    bmax_ref: float | None = None,
    runner: Runner | None = None,
) -> V1dDwGradOMatOutputs:
    """
    Manipulation of diffusion-weighted (DW) gradient vector files, b-value files,
    and b- or g-matrices with various input and output configurations.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_row_vec: Input file of 3 rows of gradients (e.g., dcm2nii-format\
            output).
        in_col_vec: Input file of 3 columns of gradients.
        in_col_mat_a: Input file of 6 columns of b- or g-matrix in 'A(FNI)'\
            diagonal first format.
        in_col_mat_t: Input file of 6 columns of b- or g-matrix in 'T(ORTOISE)'\
            row first format.
        out_row_vec: Output file of 3 rows of gradients.
        out_col_vec: Output file of 3 columns of gradients.
        out_col_mat_a: Output file of 6 columns of b- or g-matrix in 'A(FNI)'\
            diagonal first format.
        out_col_mat_t: Output file of 6 columns of b- or g-matrix in\
            'T(ORTOISE)' row first format.
        flip_x: Change sign of first column of gradients (or of the x-component\
            parts of the matrix).
        flip_y: Change sign of second column of gradients (or of the\
            y-component parts of the matrix).
        flip_z: Change sign of third column of gradients (or of the z-component\
            parts of the matrix).
        no_flip: Don't change any gradient/matrix signs (default behavior).
        in_bvals: BVAL_FILE is a file of b-values either in a single row or a\
            single column.
        out_col_bval: Switch to put a column of the bvalues as the first column\
            in the output data.
        out_row_bval_sep: Output a file of bvalues in a single row.
        out_col_bval_sep: Output a file of bvalues in a single column.
        unit_mag_out: Switch to scale each vector/matrix from the INFILE to\
            either unit or zero magnitude.
        check_abs_min: Specify the threshold to replace small negative diagonal\
            elements with zero in the input matrix.
        bref_mean_top: When averaging the reference 'b0' values, represent the\
            mean of X values in the top row.
        put_zeros_top: Add a row at the top with all zeros in the output format.
        bmax_ref: THRESH is a scalar number below which b-values are considered\
            zero or reference.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dDwGradOMatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_DW_GRAD_O_MAT___METADATA)
    cargs = []
    cargs.append("1dDW_Grad_o_Mat++")
    cargs.extend([
        "-in_row_vec",
        execution.input_file(in_row_vec)
    ])
    cargs.extend([
        "-in_col_vec",
        execution.input_file(in_col_vec)
    ])
    cargs.extend([
        "-in_col_matA",
        execution.input_file(in_col_mat_a)
    ])
    cargs.extend([
        "-in_col_matT",
        execution.input_file(in_col_mat_t)
    ])
    if flip_x:
        cargs.append("-flip_x")
    if flip_y:
        cargs.append("-flip_y")
    if flip_z:
        cargs.append("-flip_z")
    if no_flip:
        cargs.append("-no_flip")
    cargs.extend([
        "-out_row_vec",
        out_row_vec
    ])
    cargs.extend([
        "-out_col_vec",
        out_col_vec
    ])
    cargs.extend([
        "-out_col_matA",
        out_col_mat_a
    ])
    cargs.extend([
        "-out_col_matT",
        out_col_mat_t
    ])
    if in_bvals is not None:
        cargs.extend([
            "-in_bvals",
            execution.input_file(in_bvals)
        ])
    if out_col_bval:
        cargs.append("-out_col_bval")
    if out_row_bval_sep is not None:
        cargs.extend([
            "-out_row_bval_sep",
            out_row_bval_sep
        ])
    if out_col_bval_sep is not None:
        cargs.extend([
            "-out_col_bval_sep",
            out_col_bval_sep
        ])
    if unit_mag_out:
        cargs.append("-unit_mag_out")
    if check_abs_min is not None:
        cargs.extend([
            "-check_abs_min",
            str(check_abs_min)
        ])
    if bref_mean_top:
        cargs.append("-bref_mean_top")
    if put_zeros_top:
        cargs.append("-put_zeros_top")
    if bmax_ref is not None:
        cargs.extend([
            "-bmax_ref",
            str(bmax_ref)
        ])
    ret = V1dDwGradOMatOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(out_row_vec),
        out_row_bval_file=execution.output_file(out_row_bval_sep) if (out_row_bval_sep is not None) else None,
        out_col_bval_file=execution.output_file(out_row_bval_sep) if (out_row_bval_sep is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dDwGradOMatOutputs",
    "V_1D_DW_GRAD_O_MAT___METADATA",
    "v_1d_dw_grad_o_mat__",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PROJ_THRESH_METADATA = Metadata(
    id="2118a504958e3891bd47708738d41c67d1537eb5.boutiques",
    name="proj_thresh",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class ProjThreshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `proj_thresh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def proj_thresh(
    input_paths: list[InputPathType],
    threshold: float,
    runner: Runner | None = None,
) -> ProjThreshOutputs:
    """
    A tool to apply a threshold to either volumes or surfaces.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_paths: Paths to volume or surface files. Please use either\
            volumes or surfaces but not both.
        threshold: Threshold value to be applied.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ProjThreshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PROJ_THRESH_METADATA)
    cargs = []
    cargs.append("proj_thresh")
    cargs.extend([execution.input_file(f) for f in input_paths])
    cargs.append(str(threshold))
    ret = ProjThreshOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PROJ_THRESH_METADATA",
    "ProjThreshOutputs",
    "proj_thresh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ATROPOS_METADATA = Metadata(
    id="4530aeaa8993b5f6c6337cb784311667ed8f0bbf.boutiques",
    name="Atropos",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AtroposOutputs(typing.NamedTuple):
    """
    Output object returned when calling `atropos(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    classified_image: OutputPathType
    """The output labeled image with assigned labels for each voxel in the
    masked region."""
    posterior_probability_images: OutputPathType
    """Output posterior probability images in specified format."""


def atropos(
    intensity_image: str,
    initialization: str,
    mask_image: InputPathType,
    convergence: str,
    likelihood_model: str,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    bspline: str | None = None,
    partial_volume_label_set: str | None = None,
    use_partial_volume_likelihoods: typing.Literal[0, 1] | None = None,
    posterior_formulation: str | None = None,
    mrf: str | None = None,
    icm: str | None = None,
    use_random_seed: typing.Literal[0, 1] | None = None,
    minimize_memory_usage: typing.Literal[0, 1] | None = None,
    winsorize_outliers: str | None = None,
    use_euclidean_distance: typing.Literal[0, 1] | None = None,
    label_propagation: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AtroposOutputs:
    """
    Atropos is a finite mixture modeling (FMM) segmentation approach that allows for
    prior constraints including a prior label image, prior probability images,
    and/or an MRF prior to enforce spatial smoothing of the labels.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        intensity_image: One or more scalar images is specified for\
            segmentation. For scenarios with no prior information, the first scalar\
            image is used to order labelings by intensity. The optional adaptive\
            smoothing weight is applicable with prior images, specified between\
            [0,1].
        initialization: Initialize the FMM parameters. options include Random,\
            Otsu, KMeans, PriorProbabilityImages, and PriorLabelImage.
        mask_image: The required image mask defines the region to be labeled by\
            Atropos.
        convergence: Determine convergence based on mean maximum posterior\
            probability over region of interest.
        likelihood_model: Specify parametric or non-parametric likelihood\
            model. Options include Gaussian, HistogramParzenWindows,\
            ManifoldParzenWindows, among others.
        output: Output labeled image and optionally posterior probability\
            images.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, Atropos tries to infer\
            the dimensionality from the first input image.
        bspline: Parameters for B-Spline. Adaptive smoothing is applied to\
            intensity images if smoothing weights > 0.
        partial_volume_label_set: Model mixtures of classes within single\
            voxels. Specify labels for each partial volume class.
        use_partial_volume_likelihoods: Whether to use partial volume\
            likelihoods. A value of 1 considers the partial volume class separate\
            from tissue classes.
        posterior_formulation: Specify posterior probability formulation.\
            Options are Socrates, Plato, Aristotle, or Sigmoid.
        mrf: Markov Random Field parameters to enforce spatial constraints on\
            segmentation.
        icm: ICM (Iterated Conditional Modes) parameters for asynchronous\
            updating.
        use_random_seed: Initialize with a random seed or a constant seed\
            number.
        minimize_memory_usage: Minimize memory usage by calculating images on\
            the fly and storing only non-negligible pixel values.
        winsorize_outliers: Options to remove effects of outliers in\
            calculations using methods like BoxPlot or GrubbsRosner.
        use_euclidean_distance: Propagate labels throughout the mask using a\
            distance transform.
        label_propagation: Control propagation of each prior label by specified\
            lambda and boundary probability.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AtroposOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ATROPOS_METADATA)
    cargs = []
    cargs.append("Atropos")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    cargs.extend([
        "-a",
        intensity_image
    ])
    if bspline is not None:
        cargs.extend([
            "-b",
            bspline
        ])
    cargs.extend([
        "-i",
        initialization
    ])
    if partial_volume_label_set is not None:
        cargs.extend([
            "-s",
            partial_volume_label_set
        ])
    if use_partial_volume_likelihoods is not None:
        cargs.extend([
            "--use-partial-volume-likelihoods",
            str(use_partial_volume_likelihoods)
        ])
    if posterior_formulation is not None:
        cargs.extend([
            "-p",
            posterior_formulation
        ])
    cargs.extend([
        "-x",
        execution.input_file(mask_image)
    ])
    cargs.extend([
        "-c",
        convergence
    ])
    cargs.extend([
        "-k",
        likelihood_model
    ])
    if mrf is not None:
        cargs.extend([
            "-m",
            mrf
        ])
    if icm is not None:
        cargs.extend([
            "-g",
            icm
        ])
    if use_random_seed is not None:
        cargs.extend([
            "-r",
            str(use_random_seed)
        ])
    cargs.extend([
        "-o",
        output
    ])
    if minimize_memory_usage is not None:
        cargs.extend([
            "-u",
            str(minimize_memory_usage)
        ])
    if winsorize_outliers is not None:
        cargs.extend([
            "-w",
            winsorize_outliers
        ])
    if use_euclidean_distance is not None:
        cargs.extend([
            "-e",
            str(use_euclidean_distance)
        ])
    if label_propagation is not None:
        cargs.extend([
            "-l",
            label_propagation
        ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    ret = AtroposOutputs(
        root=execution.output_file("."),
        classified_image=execution.output_file(output + "_classified.nii.gz"),
        posterior_probability_images=execution.output_file("[POSTERIOR_PROBABILITY_IMAGE_FILE_NAME_FORMAT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ATROPOS_METADATA",
    "AtroposOutputs",
    "atropos",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_FSVOL_TO_BRIK_METADATA = Metadata(
    id="34a251de0c81f7f2fc2da3a56752e5c868f22a46.boutiques",
    name="@SUMA_FSvolToBRIK",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaFsvolToBrikOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_fsvol_to_brik(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_brik: OutputPathType
    """Output BRIK volume converted from FreeSurfer data"""
    out_head: OutputPathType
    """Header file for the output BRIK volume"""


def v__suma_fsvol_to_brik(
    fs_vol_data: InputPathType,
    prefix: str,
    runner: Runner | None = None,
) -> VSumaFsvolToBrikOutputs:
    """
    A script to convert COR- or .mgz files from FreeSurfer to BRIK format.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        fs_vol_data: Input FreeSurfer volume data (e.g. COR- images or .mgz\
            volume).
        prefix: Prefix for output BRIK volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaFsvolToBrikOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_FSVOL_TO_BRIK_METADATA)
    cargs = []
    cargs.append("@SUMA_FSvolToBRIK")
    cargs.append(execution.input_file(fs_vol_data))
    cargs.append(prefix)
    ret = VSumaFsvolToBrikOutputs(
        root=execution.output_file("."),
        out_brik=execution.output_file(prefix + ".BRIK"),
        out_head=execution.output_file(prefix + ".HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaFsvolToBrikOutputs",
    "V__SUMA_FSVOL_TO_BRIK_METADATA",
    "v__suma_fsvol_to_brik",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_BSET_METADATA = Metadata(
    id="a5ba928b721f328bbae969650915bdc4c218018a.boutiques",
    name="dmri_bset",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriBsetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_bset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dwi_file: OutputPathType
    """Output DWI series"""
    output_b_table_file: OutputPathType | None
    """Output b-value table"""
    output_g_table_file: OutputPathType | None
    """Output gradient table"""


def dmri_bset(
    input_dwi: InputPathType,
    output_dwi: str,
    btol: float | None = 0.05,
    bsort: bool = False,
    bmax: float | None = None,
    input_b_table: InputPathType | None = None,
    input_g_table: InputPathType | None = None,
    output_b_table: str | None = None,
    output_g_table: str | None = None,
    runner: Runner | None = None,
) -> DmriBsetOutputs:
    """
    This tool extracts a subset of volumes, b-values, and gradient directions from a
    diffusion MRI data set.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_dwi: Input DWI series.
        output_dwi: Output DWI series.
        btol: Tolerance around each single b-value (default: 0.05).
        bsort: Reorder output data by b-shell (default: maintain original\
            order).
        bmax: Extract all b-values less than or equal to a maximum.
        input_b_table: Input b-value table (default: input DWI base, .bvals\
            extension).
        input_g_table: Input gradient table (default: input DWI base, .bvecs\
            extension).
        output_b_table: Output b-value table (default: output DWI base, .bvals\
            extension).
        output_g_table: Output gradient table (default: output DWI base, .bvecs\
            extension).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriBsetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_BSET_METADATA)
    cargs = []
    cargs.append("dmri_bset")
    cargs.append(execution.input_file(input_dwi))
    cargs.append(output_dwi)
    cargs.append("[B_VALUES...]")
    if btol is not None:
        cargs.extend([
            "--btol",
            str(btol)
        ])
    if bsort:
        cargs.append("--bsort")
    if bmax is not None:
        cargs.extend([
            "--bmax",
            str(bmax)
        ])
    if input_b_table is not None:
        cargs.extend([
            "--inb",
            execution.input_file(input_b_table)
        ])
    if input_g_table is not None:
        cargs.extend([
            "--ing",
            execution.input_file(input_g_table)
        ])
    if output_b_table is not None:
        cargs.extend([
            "--outb",
            output_b_table
        ])
    if output_g_table is not None:
        cargs.extend([
            "--outg",
            output_g_table
        ])
    ret = DmriBsetOutputs(
        root=execution.output_file("."),
        output_dwi_file=execution.output_file(output_dwi),
        output_b_table_file=execution.output_file(output_b_table) if (output_b_table is not None) else None,
        output_g_table_file=execution.output_file(output_g_table) if (output_g_table is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_BSET_METADATA",
    "DmriBsetOutputs",
    "dmri_bset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_SC_METADATA = Metadata(
    id="bdd6f4bcc49d0163426eb09c58fe6f94a9a23109.boutiques",
    name="inflate_subject_sc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectScOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_sc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_output: OutputPathType
    """Inflated subject surface output."""


def inflate_subject_sc(
    runner: Runner | None = None,
) -> InflateSubjectScOutputs:
    """
    Inferred description: Tool for inflating subject surfaces, specific details
    unavailable.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectScOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_SC_METADATA)
    cargs = []
    cargs.append("inflate_subject_sc")
    cargs.append("[OPTIONS]")
    ret = InflateSubjectScOutputs(
        root=execution.output_file("."),
        inflated_output=execution.output_file("[SUBJECT_DIR]/inflated_output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_SC_METADATA",
    "InflateSubjectScOutputs",
    "inflate_subject_sc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GEN_EPI_REVIEW_PY_METADATA = Metadata(
    id="d8d2bfa4cbebb23bdbab47bb389c8686d9524ec8.boutiques",
    name="gen_epi_review.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GenEpiReviewPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gen_epi_review_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gen_epi_review_py(
    datasets: list[str],
    script_name: str | None = None,
    windows: list[str] | None = None,
    verbosity: float | None = None,
    image_size: list[float] | None = None,
    image_xoffset: float | None = None,
    image_yoffset: float | None = None,
    graph_size: list[float] | None = None,
    graph_xoffset: float | None = None,
    graph_yoffset: float | None = None,
    runner: Runner | None = None,
) -> GenEpiReviewPyOutputs:
    """
    Generate an AFNI processing script to review EPI data.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Specify input datasets for processing.
        script_name: Specify the name of the generated script.
        windows: Specify the image windows to open.
        verbosity: Specify a verbosity level.
        image_size: Set image dimensions, in pixels.
        image_xoffset: Set the X-offset for the image, in pixels.
        image_yoffset: Set the Y-offset for the image, in pixels.
        graph_size: Set graph dimensions, in pixels.
        graph_xoffset: Set the X-offset for the graph, in pixels.
        graph_yoffset: Set the Y-offset for the graph, in pixels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenEpiReviewPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GEN_EPI_REVIEW_PY_METADATA)
    cargs = []
    cargs.append("gen_epi_review.py")
    cargs.extend([
        "-dsets",
        *datasets
    ])
    if script_name is not None:
        cargs.extend([
            "-script",
            script_name
        ])
    if windows is not None:
        cargs.extend([
            "-windows",
            *windows
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    if image_size is not None:
        cargs.extend([
            "-im_size",
            *map(str, image_size)
        ])
    if image_xoffset is not None:
        cargs.extend([
            "-im_xoff",
            str(image_xoffset)
        ])
    if image_yoffset is not None:
        cargs.extend([
            "-im_yoff",
            str(image_yoffset)
        ])
    if graph_size is not None:
        cargs.extend([
            "-gr_size",
            *map(str, graph_size)
        ])
    if graph_xoffset is not None:
        cargs.extend([
            "-gr_xoff",
            str(graph_xoffset)
        ])
    if graph_yoffset is not None:
        cargs.extend([
            "-gr_yoff",
            str(graph_yoffset)
        ])
    ret = GenEpiReviewPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GEN_EPI_REVIEW_PY_METADATA",
    "GenEpiReviewPyOutputs",
    "gen_epi_review_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_GEN_3_D_METADATA = Metadata(
    id="fedbab806e12207f35c280ae3cff6fb5299d9f99.boutiques",
    name="fsl_gen_3D",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslGen3DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_gen_3_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_snapshot: OutputPathType
    """Generated 3D snapshot of the structural image"""


def fsl_gen_3_d(
    infile: InputPathType,
    outfile: InputPathType,
    runner: Runner | None = None,
) -> FslGen3DOutputs:
    """
    Tool to generate a 3D snapshot of a structural image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input structural image (e.g. input.nii.gz).
        outfile: Output 3D snapshot image (e.g. output.png).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslGen3DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_GEN_3_D_METADATA)
    cargs = []
    cargs.append("fsl_gen_3D")
    cargs.append(execution.input_file(infile))
    cargs.append(execution.input_file(outfile))
    ret = FslGen3DOutputs(
        root=execution.output_file("."),
        output_snapshot=execution.output_file(pathlib.Path(outfile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_GEN_3_D_METADATA",
    "FslGen3DOutputs",
    "fsl_gen_3_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

OCT_REGISTER_MOSAIC_METADATA = Metadata(
    id="3c0f1193be4788ada8c34632e6598409865db885.boutiques",
    name="oct_register_mosaic",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class OctRegisterMosaicOutputs(typing.NamedTuple):
    """
    Output object returned when calling `oct_register_mosaic(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_output: OutputPathType
    """The registered output volume"""


def oct_register_mosaic(
    tiles_or_mosaic_list: list[str],
    output_volume: str,
    downsample: float | None = None,
    weight_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> OctRegisterMosaicOutputs:
    """
    Tool for registering multiple OCT (Optical Coherence Tomography) tiles or a
    mosaic list into a single output volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        tiles_or_mosaic_list: OCT tile images to be registered or a file\
            listing the mosaic tiles.
        output_volume: Output registered volume.
        downsample: Use Gaussian downsampling specified number of times.
        weight_file: File with tile weights to use in tile averaging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `OctRegisterMosaicOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(OCT_REGISTER_MOSAIC_METADATA)
    cargs = []
    cargs.append("oct_register_mosaic")
    cargs.extend(tiles_or_mosaic_list)
    cargs.append(output_volume)
    if downsample is not None:
        cargs.extend([
            "-D",
            str(downsample)
        ])
    if weight_file is not None:
        cargs.extend([
            "-W",
            execution.input_file(weight_file)
        ])
    ret = OctRegisterMosaicOutputs(
        root=execution.output_file("."),
        registered_output=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "OCT_REGISTER_MOSAIC_METADATA",
    "OctRegisterMosaicOutputs",
    "oct_register_mosaic",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_BINARIZE_METADATA = Metadata(
    id="bc9047e09f0005244a935fc141f4ec627626d141.boutiques",
    name="mri_binarize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriBinarizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_binarize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_volume: OutputPathType
    """The resulting binarized volume."""


def mri_binarize(
    input_volume: InputPathType,
    output_volume: str,
    min_threshold: float | None = None,
    max_threshold: float | None = None,
    pct_threshold: float | None = None,
    rmin: float | None = None,
    rmax: float | None = None,
    fdr_threshold: float | None = None,
    match_values: list[float] | None = None,
    replace_values: list[float] | None = None,
    binval: float | None = None,
    binval_not: float | None = None,
    frame: float | None = None,
    merge_volume: InputPathType | None = None,
    mask_volume: InputPathType | None = None,
    mask_threshold: float | None = None,
    surf_name: str | None = None,
    surf_smooth: float | None = None,
    threads: float | None = None,
    ctx_wm_flag: bool = False,
    all_wm_flag: bool = False,
    ventricles_flag: bool = False,
    wm_vcsf_flag: bool = False,
    gm_flag: bool = False,
    subcort_gm_flag: bool = False,
    scm_lh_flag: bool = False,
    scm_rh_flag: bool = False,
    zero_edges_flag: bool = False,
    zero_slice_edges_flag: bool = False,
    dilate_vertex: str | None = None,
    remove_islands_flag: bool = False,
    fill_holes_flag: bool = False,
    noverbose_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> MriBinarizeOutputs:
    """
    A program to binarize a volume or volume-encoded surface file, with options to
    merge and manipulate binarized output.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume to be binarized.
        output_volume: Path to output volume.
        min_threshold: Minimum threshold (default is -inf).
        max_threshold: Maximum threshold (default is +inf).
        pct_threshold: Set threshold to capture top P% of voxels.
        rmin: Compute min threshold based on rmin times global mean.
        rmax: Compute max threshold based on rmax times global mean.
        fdr_threshold: Compute min threshold based on FDR.
        match_values: Binarize based on matching values.
        replace_values: Replace voxels with specified values. Format: V1 V2.
        binval: Set voxel value within threshold to specified value (default is\
            1).
        binval_not: Set voxel value outside threshold range to specified value\
            (default is 0).
        frame: Use specific frame of the input. 0-based index.
        merge_volume: Merge with another volume. Must be the same dimensions as\
            input volume.
        mask_volume: Mask input with a specified mask volume.
        mask_threshold: Set threshold for mask volume (default is 0.5).
        surf_name: Create a surface mesh from the binarization.
        surf_smooth: Smooth the surface mesh iteratively, specifying the number\
            of iterations.
        threads: Specify number of threads to use.
        ctx_wm_flag: Set match values for cerebral white matter.
        all_wm_flag: Set match values for all white matter.
        ventricles_flag: Set match values for ventricles and choroid.
        wm_vcsf_flag: Match for WM and ventricular CSF.
        gm_flag: Match for all WM, VCSF and background, then invert.
        subcort_gm_flag: Match for subcortical gray matter.
        scm_lh_flag: Subcortical mass for left hemisphere.
        scm_rh_flag: Subcortical mass for right hemisphere.
        zero_edges_flag: Set edge voxels to zero.
        zero_slice_edges_flag: Set edge slice voxels to zero.
        dilate_vertex: Dilate vertex to a specific target area.
        remove_islands_flag: Remove islands in the mask.
        fill_holes_flag: Remove holes in the mask.
        noverbose_flag: Suppress verbose output.
        debug_flag: Enable debugging output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriBinarizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_BINARIZE_METADATA)
    cargs = []
    cargs.append("mri_binarize")
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--o",
        output_volume
    ])
    if min_threshold is not None:
        cargs.extend([
            "--min",
            str(min_threshold)
        ])
    if max_threshold is not None:
        cargs.extend([
            "--max",
            str(max_threshold)
        ])
    if pct_threshold is not None:
        cargs.extend([
            "--pct",
            str(pct_threshold)
        ])
    if rmin is not None:
        cargs.extend([
            "--rmin",
            str(rmin)
        ])
    if rmax is not None:
        cargs.extend([
            "--rmax",
            str(rmax)
        ])
    if fdr_threshold is not None:
        cargs.extend([
            "--fdr",
            str(fdr_threshold)
        ])
    if match_values is not None:
        cargs.extend([
            "--match",
            *map(str, match_values)
        ])
    if replace_values is not None:
        cargs.extend([
            "--replace",
            *map(str, replace_values)
        ])
    if binval is not None:
        cargs.extend([
            "--binval",
            str(binval)
        ])
    if binval_not is not None:
        cargs.extend([
            "--binvalnot",
            str(binval_not)
        ])
    if frame is not None:
        cargs.extend([
            "--frame",
            str(frame)
        ])
    if merge_volume is not None:
        cargs.extend([
            "--merge",
            execution.input_file(merge_volume)
        ])
    if mask_volume is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_volume)
        ])
    if mask_threshold is not None:
        cargs.extend([
            "--mask-thresh",
            str(mask_threshold)
        ])
    if surf_name is not None:
        cargs.extend([
            "--surf",
            surf_name
        ])
    if surf_smooth is not None:
        cargs.extend([
            "--surf-smooth",
            str(surf_smooth)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if ctx_wm_flag:
        cargs.append("--ctx-wm")
    if all_wm_flag:
        cargs.append("--all-wm")
    if ventricles_flag:
        cargs.append("--ventricles")
    if wm_vcsf_flag:
        cargs.append("--wm+vcsf")
    if gm_flag:
        cargs.append("--gm")
    if subcort_gm_flag:
        cargs.append("--subcort-gm")
    if scm_lh_flag:
        cargs.append("--scm-lh")
    if scm_rh_flag:
        cargs.append("--scm-rh")
    if zero_edges_flag:
        cargs.append("--zero-edges")
    if zero_slice_edges_flag:
        cargs.append("--zero-slice-edges")
    if dilate_vertex is not None:
        cargs.extend([
            "--dilate-vertex",
            dilate_vertex
        ])
    if remove_islands_flag:
        cargs.append("--remove-islands")
    if fill_holes_flag:
        cargs.append("--fill-holes")
    if noverbose_flag:
        cargs.append("--noverbose")
    if debug_flag:
        cargs.append("--debug")
    ret = MriBinarizeOutputs(
        root=execution.output_file("."),
        out_volume=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_BINARIZE_METADATA",
    "MriBinarizeOutputs",
    "mri_binarize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DETREND_METADATA = Metadata(
    id="e1acbbed353dee123a530befb4df733e98383a20.boutiques",
    name="3dDetrend",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDetrendOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_detrend(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Output file."""


def v_3d_detrend(
    in_file: InputPathType,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    runner: Runner | None = None,
) -> V3dDetrendOutputs:
    """
    This program removes components from voxel time series using linear least
    squares.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3ddetrend.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDetrendOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DETREND_METADATA)
    cargs = []
    cargs.append("3dDetrend")
    cargs.append(execution.input_file(in_file))
    if outputtype is not None:
        cargs.append(outputtype)
    ret = V3dDetrendOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_detrend"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDetrendOutputs",
    "V_3D_DETREND_METADATA",
    "v_3d_detrend",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

C3D_AFFINE_TOOL_METADATA = Metadata(
    id="4d680bc675d44917986d0a7dc537117e07489d00.boutiques",
    name="c3d_affine_tool",
    package="c3d",
    container_image_tag="pyushkevich/itksnap:v3.8.2",
)


class C3dAffineToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `c3d_affine_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    itk_transform_outfile: OutputPathType | None
    """Output ITK transform file."""
    irtk_transform_outfile: OutputPathType | None
    """Output IRTK transform file."""
    matrix_transform_outfile: OutputPathType | None
    """Write output matrix."""


def c3d_affine_tool(
    transform_file: InputPathType | None = None,
    reference_file: InputPathType | None = None,
    source_file: InputPathType | None = None,
    sform_file: InputPathType | None = None,
    invert: bool = False,
    determinant: bool = False,
    multiply: bool = False,
    sqrt: bool = False,
    itk_transform: InputPathType | None = None,
    irtk_transform: InputPathType | None = None,
    fsl2ras: bool = False,
    ras2fsl: bool = False,
    out_itk_transform: str | None = None,
    out_irtk_transform: str | None = None,
    out_matfile: str | None = None,
    info: bool = False,
    info_full: bool = False,
    runner: Runner | None = None,
) -> C3dAffineToolOutputs:
    """
    RAS affine transform tool.
    
    Author: Convert3D Developers
    
    URL: http://www.itksnap.org/pmwiki/pmwiki.php?n=Convert3D.Convert3D
    
    Args:
        transform_file: file or string representing the transform.
        reference_file: Set reference (fixed) image - only for -fsl2ras and\
            -ras2fsl.
        source_file: Set source (moving) image - only for -fsl2ras and\
            -ras2fsl.
        sform_file: Read matrix from NifTI sform.
        invert: Invert matrix.
        determinant: Print the determinant.
        multiply: Multiply matrices.
        sqrt: Matrix square root (i.e., Q s.t. A = Q * Q).
        itk_transform: Import ITK transform.
        irtk_transform: Import IRTK .dof format transform.
        fsl2ras: Convert FSL to RAS.
        ras2fsl: Convert RAS to FSL.
        out_itk_transform: Export ITK transform.
        out_irtk_transform: Export IRTK .dof format transform.
        out_matfile: Write output matrix.
        info: Print matrix.
        info_full: Print matrix and more detail about the transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `C3dAffineToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(C3D_AFFINE_TOOL_METADATA)
    cargs = []
    cargs.append("c3d_affine_tool")
    if transform_file is not None:
        cargs.append(execution.input_file(transform_file))
    if reference_file is not None:
        cargs.extend([
            "-ref",
            execution.input_file(reference_file)
        ])
    if source_file is not None:
        cargs.extend([
            "-src",
            execution.input_file(source_file)
        ])
    if sform_file is not None:
        cargs.extend([
            "-sform",
            execution.input_file(sform_file)
        ])
    if invert:
        cargs.append("-inv")
    if determinant:
        cargs.append("-det")
    if multiply:
        cargs.append("-mult")
    if sqrt:
        cargs.append("-sqrt")
    if itk_transform is not None:
        cargs.extend([
            "-itk",
            execution.input_file(itk_transform)
        ])
    if irtk_transform is not None:
        cargs.extend([
            "-irtk",
            execution.input_file(irtk_transform)
        ])
    if fsl2ras:
        cargs.append("-fsl2ras")
    if ras2fsl:
        cargs.append("-ras2fsl")
    if out_itk_transform is not None:
        cargs.extend([
            "-oitk",
            out_itk_transform
        ])
    if out_irtk_transform is not None:
        cargs.extend([
            "-oirtk",
            out_irtk_transform
        ])
    if out_matfile is not None:
        cargs.extend([
            "-o",
            out_matfile
        ])
    if info:
        cargs.append("-info")
    if info_full:
        cargs.append("-info-full")
    ret = C3dAffineToolOutputs(
        root=execution.output_file("."),
        itk_transform_outfile=execution.output_file(out_itk_transform) if (out_itk_transform is not None) else None,
        irtk_transform_outfile=execution.output_file(out_irtk_transform) if (out_irtk_transform is not None) else None,
        matrix_transform_outfile=execution.output_file(out_matfile) if (out_matfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "C3D_AFFINE_TOOL_METADATA",
    "C3dAffineToolOutputs",
    "c3d_affine_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EXVIVO_STRIP_METADATA = Metadata(
    id="656236688df22fbf848368ed1bf41f141adaf38d.boutiques",
    name="mri_exvivo_strip",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriExvivoStripOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_exvivo_strip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Processed output MRI volume"""
    prediction_output: OutputPathType | None
    """Prediction volume if specified"""
    normalized_output: OutputPathType | None
    """Normalized volume if specified"""


def mri_exvivo_strip(
    invol: InputPathType,
    outvol: str,
    hemi: str,
    pred: InputPathType | None = None,
    norm: InputPathType | None = None,
    fv: bool = False,
    uthresh: float | None = None,
    border: float | None = None,
    multichannel: bool = False,
    model: InputPathType | None = None,
    wts: InputPathType | None = None,
    gpu: float | None = None,
    runner: Runner | None = None,
) -> MriExvivoStripOutputs:
    """
    Tool for processing MRI volumes for ex vivo data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        invol: Input MRI volume.
        outvol: Output MRI volume.
        hemi: Hemi to process.
        pred: Write prediction volume.
        norm: Write normalized volume.
        fv: Bring up freeview to show results.
        uthresh: Specify threshold to erase above.
        border: Number of border voxels to set threshold at.
        multichannel: Specify that data has multiple channels.
        model: Use alternative model file.
        wts: Weight filename.
        gpu: GPU number - if not supplied, CPU is used.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriExvivoStripOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EXVIVO_STRIP_METADATA)
    cargs = []
    cargs.append("mri_exvivo_strip")
    cargs.extend([
        "-i",
        execution.input_file(invol)
    ])
    cargs.extend([
        "-o",
        outvol
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    if pred is not None:
        cargs.extend([
            "--pred",
            execution.input_file(pred)
        ])
    if norm is not None:
        cargs.extend([
            "--norm",
            execution.input_file(norm)
        ])
    if fv:
        cargs.append("--fv")
    if uthresh is not None:
        cargs.extend([
            "--uthresh",
            str(uthresh)
        ])
    if border is not None:
        cargs.extend([
            "--border",
            str(border)
        ])
    if multichannel:
        cargs.append("--multichannel")
    if model is not None:
        cargs.extend([
            "--model",
            execution.input_file(model)
        ])
    if wts is not None:
        cargs.extend([
            "--wts",
            execution.input_file(wts)
        ])
    if gpu is not None:
        cargs.extend([
            "--gpu",
            str(gpu)
        ])
    ret = MriExvivoStripOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(outvol),
        prediction_output=execution.output_file(pathlib.Path(pred).name) if (pred is not None) else None,
        normalized_output=execution.output_file(pathlib.Path(norm).name) if (norm is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EXVIVO_STRIP_METADATA",
    "MriExvivoStripOutputs",
    "mri_exvivo_strip",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_METADATA = Metadata(
    id="b8be8a3006d75208ed11a3cade7f3dc203569638.boutiques",
    name="possum",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PossumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix: OutputPathType
    """Output matrix file generated by possum"""


def possum(
    input_volume: InputPathType,
    mr_parameters: InputPathType,
    motion_matrix: InputPathType,
    pulse_sequence: str,
    rf_slice_profile: InputPathType,
    output_signal: str,
    event_matrix: InputPathType,
    verbose: bool = False,
    help_: bool = False,
    kcoord: bool = False,
    b0_inhomogeneities: str | None = None,
    extra_b0_inhomogeneities: InputPathType | None = None,
    b0_inhomogeneities_timecourse: InputPathType | None = None,
    rf_inhomogeneity_receive: InputPathType | None = None,
    rf_inhomogeneity_transmit: InputPathType | None = None,
    activation_volume: InputPathType | None = None,
    activation_timecourse: InputPathType | None = None,
    activation_4d_volume: InputPathType | None = None,
    activation_4d_timecourse: InputPathType | None = None,
    level: str | None = None,
    num_procs: float | None = None,
    proc_id: float | None = None,
    no_speedup: bool = False,
    rf_average: bool = False,
    runner: Runner | None = None,
) -> PossumOutputs:
    """
    Positron emission tomography (PET) simulation tool as part of FSL suite.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_volume: Input 4D volume filename.
        mr_parameters: Input matrix filename containing MR parameters.
        motion_matrix: Input motion matrix filename (time(s) Tx(m) Ty(m) Tz(m)\
            Rx(rad) Ry(rad) Rz(rad)).
        pulse_sequence: Input matrix basename for pulse sequence files (.posx,\
            .posy, etc.).
        rf_slice_profile: Input matrix filename containing RF slice profile.
        output_signal: Output matrix filename for the signal.
        event_matrix: Main event matrix file [(t(s), rf_ang(rad),\
            rf_freq_band(Hz), rf_cent_freq(Hz), ...)].
        verbose: Switch on diagnostic messages.
        help_: Display help message.
        kcoord: Save the k-space coordinates.
        b0_inhomogeneities: B0 inhomogeneities due to susceptibility\
            differences (basename).
        extra_b0_inhomogeneities: B0 inhomogeneities due to an extra field.
        b0_inhomogeneities_timecourse: B0 inhomogeneities timecourse file.
        rf_inhomogeneity_receive: RF inhomogeneity - receive.
        rf_inhomogeneity_transmit: RF inhomogeneity - transmit.
        activation_volume: Activation volume file.
        activation_timecourse: Activation time course file.
        activation_4d_volume: Activation 4D volume file.
        activation_4d_timecourse: Activation 4D time course file.
        level: Level of processing: 1.no motion//basic B0, 2.motion//basic B0,\
            3.motion//full B0, 4.no motion//time changing B0.
        num_procs: Number of processors available for parallelisation.
        proc_id: ID of the processor.
        no_speedup: If ON, will not do the speedup but perform signal\
            calculation for all slices for each voxel.
        rf_average: If ON, it will use RF angle averaging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_METADATA)
    cargs = []
    cargs.append("possum")
    cargs.extend([
        "--inp",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--mrpar",
        execution.input_file(mr_parameters)
    ])
    cargs.extend([
        "--motion",
        execution.input_file(motion_matrix)
    ])
    cargs.extend([
        "--pulse",
        pulse_sequence
    ])
    cargs.extend([
        "--slcprof",
        execution.input_file(rf_slice_profile)
    ])
    cargs.extend([
        "--out",
        output_signal
    ])
    cargs.extend([
        "--mainmatx",
        execution.input_file(event_matrix)
    ])
    if verbose:
        cargs.append("--verbose")
    if help_:
        cargs.append("--help")
    if kcoord:
        cargs.append("--kcoord")
    if b0_inhomogeneities is not None:
        cargs.extend([
            "--b0p",
            b0_inhomogeneities
        ])
    if extra_b0_inhomogeneities is not None:
        cargs.extend([
            "--b0extra",
            execution.input_file(extra_b0_inhomogeneities)
        ])
    if b0_inhomogeneities_timecourse is not None:
        cargs.extend([
            "--b0time",
            execution.input_file(b0_inhomogeneities_timecourse)
        ])
    if rf_inhomogeneity_receive is not None:
        cargs.extend([
            "--rfr",
            execution.input_file(rf_inhomogeneity_receive)
        ])
    if rf_inhomogeneity_transmit is not None:
        cargs.extend([
            "--rft",
            execution.input_file(rf_inhomogeneity_transmit)
        ])
    if activation_volume is not None:
        cargs.extend([
            "--activ",
            execution.input_file(activation_volume)
        ])
    if activation_timecourse is not None:
        cargs.extend([
            "--activt",
            execution.input_file(activation_timecourse)
        ])
    if activation_4d_volume is not None:
        cargs.extend([
            "--activ4D",
            execution.input_file(activation_4d_volume)
        ])
    if activation_4d_timecourse is not None:
        cargs.extend([
            "--activt4D",
            execution.input_file(activation_4d_timecourse)
        ])
    if level is not None:
        cargs.extend([
            "--lev",
            level
        ])
    if num_procs is not None:
        cargs.extend([
            "--nproc",
            str(num_procs)
        ])
    if proc_id is not None:
        cargs.extend([
            "--procid",
            str(proc_id)
        ])
    if no_speedup:
        cargs.append("--nospeedup")
    if rf_average:
        cargs.append("--rfavg")
    ret = PossumOutputs(
        root=execution.output_file("."),
        output_matrix=execution.output_file("[OUTPUT_MATRIX].mat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_METADATA",
    "PossumOutputs",
    "possum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLVBM_3_PROC_METADATA = Metadata(
    id="e412ceb5c621d60c9b9b10de2a0a6700c42898c2.boutiques",
    name="fslvbm_3_proc",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Fslvbm3ProcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslvbm_3_proc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_directory: OutputPathType
    """Output data directory"""


def fslvbm_3_proc(
    arch: str | None = None,
    coprocessor: str | None = None,
    coprocessor_multi: str | None = None,
    coprocessor_class: str | None = None,
    coprocessor_class_strict: bool = False,
    coprocessor_toolkit: str | None = None,
    not_requeueable: bool = False,
    jobhold: str | None = None,
    array_hold: str | None = None,
    logdir: str | None = None,
    mailoptions: str | None = None,
    mailto: str | None = None,
    name: str | None = None,
    priority: str | None = None,
    queue_: str | None = None,
    resource_: str | None = None,
    delete_job: str | None = None,
    memory_gb: float | None = None,
    parallel_env_threads: str | None = None,
    array_task: str | None = None,
    array_native: str | None = None,
    number_jobscripts: float | None = None,
    keep_jobscript: bool = False,
    coprocessor_name: str | None = None,
    has_queues: bool = False,
    project: str | None = None,
    submit_scheduler: bool = False,
    runtime_limit: float | None = None,
    show_config: bool = False,
    verbose: bool = False,
    version: bool = False,
    config_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> Fslvbm3ProcOutputs:
    """
    Pipeline for voxel-based morphometry analysis using FSL tools.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        arch: Specify architecture.
        coprocessor: Specify coprocessor.
        coprocessor_multi: Specify multiple coprocessors.
        coprocessor_class: Specify coprocessor class.
        coprocessor_class_strict: Use strict class matching for coprocessor.
        coprocessor_toolkit: Specify coprocessor toolkit.
        not_requeueable: Do not requeue the job.
        jobhold: Job to hold.
        array_hold: Array hold.
        logdir: Specify log directory.
        mailoptions: Specify mail options.
        mailto: Specify mail recipient.
        name: Job name.
        priority: Job priority.
        queue_: Queue to submit to.
        resource_: Resource identifier.
        delete_job: Delete specified job.
        memory_gb: Memory (GB).
        parallel_env_threads: Parallel environment and threads.
        array_task: Array task file.
        array_native: Array native specification.
        number_jobscripts: Keep number of job scripts.
        keep_jobscript: Keep job script.
        coprocessor_name: Specify coprocessor name.
        has_queues: Specify queues.
        project: Specify project name.
        submit_scheduler: Submit to Scheduler.
        runtime_limit: Specify runtime limit in minutes.
        show_config: Show configuration.
        verbose: Verbose output.
        version: Version information.
        config_file: Specify configuration file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fslvbm3ProcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLVBM_3_PROC_METADATA)
    cargs = []
    cargs.append("fslvbm_3_proc")
    if arch is not None:
        cargs.extend([
            "-a",
            arch
        ])
    if coprocessor is not None:
        cargs.extend([
            "-c",
            coprocessor
        ])
    if coprocessor_multi is not None:
        cargs.extend([
            "--coprocessor_multi",
            coprocessor_multi
        ])
    if coprocessor_class is not None:
        cargs.extend([
            "--coprocessor_class",
            coprocessor_class
        ])
    if coprocessor_class_strict:
        cargs.append("--coprocessor_class_strict")
    if coprocessor_toolkit is not None:
        cargs.extend([
            "--coprocessor_toolkit",
            coprocessor_toolkit
        ])
    if not_requeueable:
        cargs.append("-F")
    if jobhold is not None:
        cargs.extend([
            "-j",
            jobhold
        ])
    if array_hold is not None:
        cargs.extend([
            "--array_hold",
            array_hold
        ])
    if logdir is not None:
        cargs.extend([
            "-l",
            logdir
        ])
    if mailoptions is not None:
        cargs.extend([
            "-m",
            mailoptions
        ])
    if mailto is not None:
        cargs.extend([
            "-M",
            mailto
        ])
    if name is not None:
        cargs.extend([
            "-N",
            name
        ])
    if priority is not None:
        cargs.extend([
            "-p",
            priority
        ])
    if queue_ is not None:
        cargs.extend([
            "-q",
            queue_
        ])
    if resource_ is not None:
        cargs.extend([
            "-r",
            resource_
        ])
    if delete_job is not None:
        cargs.extend([
            "--delete_job",
            delete_job
        ])
    if memory_gb is not None:
        cargs.extend([
            "-R",
            str(memory_gb)
        ])
    if parallel_env_threads is not None:
        cargs.extend([
            "-s",
            parallel_env_threads
        ])
    if array_task is not None:
        cargs.extend([
            "-t",
            array_task
        ])
    if array_native is not None:
        cargs.extend([
            "--array_native",
            array_native
        ])
    if number_jobscripts is not None:
        cargs.extend([
            "-x",
            str(number_jobscripts)
        ])
    if keep_jobscript:
        cargs.append("--keep_jobscript")
    if coprocessor_name is not None:
        cargs.extend([
            "--has_coprocessor",
            coprocessor_name
        ])
    if has_queues:
        cargs.append("--has_queues")
    if project is not None:
        cargs.extend([
            "--project",
            project
        ])
    if submit_scheduler:
        cargs.append("-S")
    if runtime_limit is not None:
        cargs.extend([
            "-T",
            str(runtime_limit)
        ])
    if show_config:
        cargs.append("--show_config")
    if verbose:
        cargs.append("-v")
    if version:
        cargs.append("-V")
    if config_file is not None:
        cargs.extend([
            "-z",
            execution.input_file(config_file)
        ])
    ret = Fslvbm3ProcOutputs(
        root=execution.output_file("."),
        output_directory=execution.output_file("fslvbm3a"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLVBM_3_PROC_METADATA",
    "Fslvbm3ProcOutputs",
    "fslvbm_3_proc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKSAMPLE_METADATA = Metadata(
    id="0fd3b8818e87fff260e091a14a0639a496a49125.boutiques",
    name="tcksample",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TcksampleConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TcksampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tcksample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    values_: OutputPathType
    """the output sampled values"""


def tcksample(
    tracks: InputPathType,
    image: InputPathType,
    values_: str,
    stat_tck: str | None = None,
    nointerp: bool = False,
    precise: bool = False,
    use_tdi_fraction: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TcksampleConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TcksampleOutputs:
    """
    Sample values of an associated image along tracks.
    
    By default, the value of the underlying image at each point along the track
    is written to either an ASCII file (with all values for each track on the
    same line), or a track scalar file (.tsf). Alternatively, some statistic can
    be taken from the values along each streamline and written to a vector file.
    
    References:
    
    * If using -precise option: Smith, R. E.; Tournier, J.-D.; Calamante, F. &
    Connelly, A. SIFT: Spherical-deconvolution informed filtering of
    tractograms. NeuroImage, 2013, 67, 298-312.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        tracks: the input track file.
        image: the image to be sampled.
        values_: the output sampled values.
        stat_tck: compute some statistic from the values along each streamline\
            (options are: mean,median,min,max).
        nointerp: do not use trilinear interpolation when sampling image values.
        precise: use the precise mechanism for mapping streamlines to voxels\
            (obviates the need for trilinear interpolation) (only applicable if\
            some per-streamline statistic is requested).
        use_tdi_fraction: each streamline is assigned a fraction of the image\
            intensity in each voxel based on the fraction of the track density\
            contributed by that streamline (this is only appropriate for processing\
            a whole-brain tractogram, and images for which the quantiative\
            parameter is additive).
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TcksampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKSAMPLE_METADATA)
    cargs = []
    cargs.append("tcksample")
    if stat_tck is not None:
        cargs.extend([
            "-stat_tck",
            stat_tck
        ])
    if nointerp:
        cargs.append("-nointerp")
    if precise:
        cargs.append("-precise")
    if use_tdi_fraction:
        cargs.append("-use_tdi_fraction")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(tracks))
    cargs.append(execution.input_file(image))
    cargs.append(values_)
    ret = TcksampleOutputs(
        root=execution.output_file("."),
        values_=execution.output_file(values_),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKSAMPLE_METADATA",
    "TcksampleConfig",
    "TcksampleOutputs",
    "tcksample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DEFECT2SEG_METADATA = Metadata(
    id="8cc085b9f5ac3b7cb657915baccb8e34277b70f2.boutiques",
    name="defect2seg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Defect2segOutputs(typing.NamedTuple):
    """
    Output object returned when calling `defect2seg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_segmentation: OutputPathType
    """Resulting defect segmentation volume"""


def defect2seg(
    output_seg: InputPathType,
    template: InputPathType,
    left_hemisphere: list[str] | None = None,
    right_hemisphere: list[str] | None = None,
    subject: str | None = None,
    lh_only: bool = False,
    rh_only: bool = False,
    cortex: bool = False,
    no_cortex: bool = False,
    runner: Runner | None = None,
) -> Defect2segOutputs:
    """
    Converts surface defect labels into a segmentation volume and pointsets.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_seg: Output segmentation volume.
        template: Template for segmentation.
        left_hemisphere: Left hemisphere inputs: surface, defect labels,\
            pointset, and offset.
        right_hemisphere: Right hemisphere inputs: surface, defect labels,\
            pointset, and offset.
        subject: Subject identifier, sets default values for other parameters.
        lh_only: Consider only left hemisphere defects.
        rh_only: Consider only right hemisphere defects.
        cortex: Constrain defects to within cortex.
        no_cortex: Allow defects outside of cortex.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Defect2segOutputs`).
    """
    if left_hemisphere is not None and not (len(left_hemisphere) <= 4): 
        raise ValueError(f"Length of 'left_hemisphere' must be less than 4 but was {len(left_hemisphere)}")
    if right_hemisphere is not None and not (len(right_hemisphere) <= 4): 
        raise ValueError(f"Length of 'right_hemisphere' must be less than 4 but was {len(right_hemisphere)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DEFECT2SEG_METADATA)
    cargs = []
    cargs.append("defect2seg")
    cargs.extend([
        "--o",
        execution.input_file(output_seg)
    ])
    cargs.extend([
        "--t",
        execution.input_file(template)
    ])
    if left_hemisphere is not None:
        cargs.extend([
            "--lh",
            *left_hemisphere
        ])
    if right_hemisphere is not None:
        cargs.extend([
            "--rh",
            *right_hemisphere
        ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if lh_only:
        cargs.append("--lh-only")
    if rh_only:
        cargs.append("--rh-only")
    if cortex:
        cargs.append("--cortex")
    if no_cortex:
        cargs.append("--no-cortex")
    ret = Defect2segOutputs(
        root=execution.output_file("."),
        output_segmentation=execution.output_file(pathlib.Path(output_seg).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DEFECT2SEG_METADATA",
    "Defect2segOutputs",
    "defect2seg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSR_IMPORT_METADATA = Metadata(
    id="0f4f0456c8df72ab9210f36b4e8bfb88e6ceba62.boutiques",
    name="fsr-import",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsrImportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsr_import(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_t1w: OutputPathType
    """Output directory for T1-weighted images"""
    out_t2w: OutputPathType
    """Output directory for T2-weighted images"""
    out_flair: OutputPathType
    """Output directory for FLAIR images"""
    out_custom_modes: OutputPathType
    """Output directory for custom modality images based on mode"""


def fsr_import(
    outdir: str,
    force_update: bool = False,
    no_conform: bool = False,
    hires: bool = False,
    runner: Runner | None = None,
) -> FsrImportOutputs:
    """
    Copies/converts data into a directory structure for samseg-expected format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outdir: Root directory for output data.
        force_update: Update files regardless of timestamp.
        no_conform: Do not conform inputs to 1mm, 256 dimensions.
        hires: Same as --no-conform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsrImportOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSR_IMPORT_METADATA)
    cargs = []
    cargs.append("fsr-import")
    cargs.extend([
        "--o",
        outdir
    ])
    cargs.append("[T1W...]")
    cargs.append("[T2W...]")
    cargs.append("[FLAIR...]")
    cargs.append("[CUSTOM_MODES...]")
    if force_update:
        cargs.append("--force-update")
    if no_conform:
        cargs.append("--no-conform")
    if hires:
        cargs.append("--hires")
    ret = FsrImportOutputs(
        root=execution.output_file("."),
        out_t1w=execution.output_file(outdir + "/t1w/*.mgz"),
        out_t2w=execution.output_file(outdir + "/t2w/*.mgz"),
        out_flair=execution.output_file(outdir + "/flair/*.mgz"),
        out_custom_modes=execution.output_file(outdir + "/*/*.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSR_IMPORT_METADATA",
    "FsrImportOutputs",
    "fsr_import",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SMOOTH_IMAGE_METADATA = Metadata(
    id="c743ecca2407454064c39d3994944e2822b5560a.boutiques",
    name="SmoothImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SmoothImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `smooth_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    smoothed_image: OutputPathType
    """The output smoothed image file."""


def smooth_image(
    image_dimension: int,
    image_ext: InputPathType,
    smoothing_sigma: str,
    out_image_ext: str,
    sigma_units: typing.Literal[0, 1] | None = None,
    median_filter: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> SmoothImageOutputs:
    """
    SmoothImage allows smoothing of images with adjustable sigma values, offering
    optional median filtering functionality.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Specifies the dimensionality of the image.
        image_ext: The input image file to be smoothed.
        smoothing_sigma: The sigma value for smoothing. A separate sigma may be\
            specified for each dimension, e.g., '1.5x1x2'.
        out_image_ext: The output smoothed image file.
        sigma_units: Determines if sigma is in spacing units (1) or not (0).\
            Default is 0.
        median_filter: Whether to use median filter. Default is 0. If using\
            median filter, sigma represents the radius in voxels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SmoothImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SMOOTH_IMAGE_METADATA)
    cargs = []
    cargs.append("SmoothImage")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(image_ext))
    cargs.append(smoothing_sigma)
    cargs.append(out_image_ext)
    if sigma_units is not None:
        cargs.append(str(sigma_units))
    if median_filter is not None:
        cargs.append(str(median_filter))
    ret = SmoothImageOutputs(
        root=execution.output_file("."),
        smoothed_image=execution.output_file(out_image_ext),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SMOOTH_IMAGE_METADATA",
    "SmoothImageOutputs",
    "smooth_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_X_METADATA = Metadata(
    id="92fc476ae5e966d3c5014f57b61d18334a4b32e8.boutiques",
    name="tbss_x",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class TbssXOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_x(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_x(
    scalar_dirs: list[str],
    vector_dirs: list[str],
    runner: Runner | None = None,
) -> TbssXOutputs:
    """
    TBSS cross-subject script for processing scalar and vector directories.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        scalar_dirs: List of scalar directories (e.g., F1, F2).
        vector_dirs: List of vector directories (e.g., D1, D2).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TbssXOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_X_METADATA)
    cargs = []
    cargs.append("tbss_x")
    cargs.extend(scalar_dirs)
    cargs.extend(vector_dirs)
    ret = TbssXOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_X_METADATA",
    "TbssXOutputs",
    "tbss_x",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SWAP_VOXELWISE_METADATA = Metadata(
    id="4d3f862f263904d851a583fa7d717c4e6949c262.boutiques",
    name="swap_voxelwise",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SwapVoxelwiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `swap_voxelwise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reordered_output: OutputPathType | None
    """Output file with reordered vectors (default name 'reordered.nii.gz')"""


def swap_voxelwise(
    vectors_file_list: InputPathType,
    mask: InputPathType,
    scalars_file_list: InputPathType | None = None,
    output_base_name: str | None = "reordered",
    reorder_mode: str | None = "voxels",
    init_mask: InputPathType | None = None,
    crossing_thresh: float | None = 0.1,
    runner: Runner | None = None,
) -> SwapVoxelwiseOutputs:
    """
    Reordering of vectors with direction preservation.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        vectors_file_list: Text file containing list of vectors.
        mask: Filename of brain mask or skeleton.
        scalars_file_list: Text file containing list of scalars.
        output_base_name: Output base name.
        reorder_mode: Reordering mode - choose between 'voxels' (default) or\
            'volumes'.
        init_mask: Filename of initialization mask.
        crossing_thresh: Threshold for considering a crossing fibre region -\
            default=0.1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SwapVoxelwiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SWAP_VOXELWISE_METADATA)
    cargs = []
    cargs.append("swap_voxelwise")
    cargs.extend([
        "-v",
        execution.input_file(vectors_file_list)
    ])
    if scalars_file_list is not None:
        cargs.extend([
            "-s",
            execution.input_file(scalars_file_list)
        ])
    cargs.extend([
        "-m",
        execution.input_file(mask)
    ])
    if output_base_name is not None:
        cargs.extend([
            "-b",
            output_base_name
        ])
    if reorder_mode is not None:
        cargs.extend([
            "--mode",
            reorder_mode
        ])
    if init_mask is not None:
        cargs.extend([
            "--initmask",
            execution.input_file(init_mask)
        ])
    if crossing_thresh is not None:
        cargs.extend([
            "--xthresh",
            str(crossing_thresh)
        ])
    cargs.append("-V")
    ret = SwapVoxelwiseOutputs(
        root=execution.output_file("."),
        reordered_output=execution.output_file(output_base_name + ".nii.gz") if (output_base_name is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SWAP_VOXELWISE_METADATA",
    "SwapVoxelwiseOutputs",
    "swap_voxelwise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSR_GETXOPTS_METADATA = Metadata(
    id="224fcae72cefe1195f88d86eb1986d98d2293a58.boutiques",
    name="fsr-getxopts",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsrGetxoptsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsr_getxopts(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsr_getxopts(
    help_: bool = False,
    runner: Runner | None = None,
) -> FsrGetxoptsOutputs:
    """
    Tool to retrieve extended options for a specific context or configuration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        help_: Display the help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsrGetxoptsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSR_GETXOPTS_METADATA)
    cargs = []
    cargs.append("fsr-getxopts")
    if help_:
        cargs.append("--help")
    ret = FsrGetxoptsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSR_GETXOPTS_METADATA",
    "FsrGetxoptsOutputs",
    "fsr_getxopts",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RESAMPLE_IMAGE_METADATA = Metadata(
    id="09cbfa81905a40fb69e7164887ae36302a83bb75.boutiques",
    name="ResampleImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ResampleImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `resample_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resampled_output_image: OutputPathType
    """The resultant image after resampling."""


def resample_image(
    image_dimension: int,
    input_image: InputPathType,
    output_image: InputPathType,
    size_spacing: str,
    interpolate_type: typing.Literal["0", "1", "2", "3", "4"] | None = None,
    pixeltype: typing.Literal["0", "1", "2", "3", "4", "5", "6", "7"] | None = None,
    runner: Runner | None = None,
) -> ResampleImageOutputs:
    """
    ResampleImage is a tool used to resample images to specified sizes and spacings,
    using various interpolation methods and pixel types.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimension of the image to be resampled.
        input_image: The image file to be resampled.
        output_image: The output image file after resampling.
        size_spacing: Resampling size and spacing specification, e.g., 'MxNxO'.
        interpolate_type: Specifies the interpolation type. 0: linear\
            (default), 1: nearest-neighbor, 2: gaussian, 3: windowedSinc, 4:\
            B-Spline.
        pixeltype: Specifies the pixel type of the output image. 0: char, 1:\
            unsigned char, 2: short, 3: unsigned short, 4: int, 5: unsigned int, 6:\
            float (default), 7: double.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ResampleImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RESAMPLE_IMAGE_METADATA)
    cargs = []
    cargs.append("ResampleImage")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    cargs.append(size_spacing)
    if interpolate_type is not None:
        cargs.append(interpolate_type)
    if pixeltype is not None:
        cargs.append(pixeltype)
    ret = ResampleImageOutputs(
        root=execution.output_file("."),
        resampled_output_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RESAMPLE_IMAGE_METADATA",
    "ResampleImageOutputs",
    "resample_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GCATRAIN_METADATA = Metadata(
    id="eee9b89002e0f2e263128edc3af126a1ada69cbf.boutiques",
    name="gcatrain",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GcatrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gcatrain(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gcatrain(
    gcadir: str,
    subjectlistfile: InputPathType,
    init_subject_transform: list[str],
    seg_file: InputPathType,
    source_subjects_dir: str,
    num_iters: float | None = None,
    num_threads: float | None = None,
    exclude_file: InputPathType | None = None,
    exclude_subject: str | None = None,
    symmetric_atlas: bool = False,
    color_table: InputPathType | None = None,
    no_submit: bool = False,
    mail_flag: bool = False,
    no_strict: bool = False,
    gcareg_iters: bool = False,
    prep_only: bool = False,
    nu10_flag: bool = False,
    nu12_flag: bool = False,
    no_emreg: bool = False,
    runner: Runner | None = None,
) -> GcatrainOutputs:
    """
    GCA training tool for building a GCA from a group of manually labeled subjects.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gcadir: Directory for the new SUBJECTS_DIR.
        subjectlistfile: The list of subjects to include.
        init_subject_transform: Initialization subject and its talairach\
            transform.
        seg_file: Segmentation file (e.g. seg_edited.mgz).
        source_subjects_dir: Source SUBJECTS_DIR for data.
        num_iters: Number of iterations.
        num_threads: Number of threads to use.
        exclude_file: File listing subjects to exclude, useful for jackknifing.
        exclude_subject: Exclude a single subject, useful for jackknifing.
        symmetric_atlas: Create a symmetric atlas.
        color_table: Colortable for segmentation labels (not needed).
        no_submit: Run serially without pbsubmit.
        mail_flag: Mail to user when jobs are pbsubmitted or finished.
        no_strict: Do not require FS build stamps to match across iterations.
        gcareg_iters: Set to 1 for testing.
        prep_only: Execute preparation steps only.
        nu10_flag: Run with nu10 settings.
        nu12_flag: Run with nu12 settings (default).
        no_emreg: Do not use mri_em_register.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GcatrainOutputs`).
    """
    if (len(init_subject_transform) != 2): 
        raise ValueError(f"Length of 'init_subject_transform' must be 2 but was {len(init_subject_transform)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(GCATRAIN_METADATA)
    cargs = []
    cargs.append("gcatrain")
    cargs.extend([
        "--g",
        gcadir
    ])
    cargs.extend([
        "--f",
        execution.input_file(subjectlistfile)
    ])
    cargs.extend([
        "--init",
        *init_subject_transform
    ])
    cargs.extend([
        "--seg",
        execution.input_file(seg_file)
    ])
    cargs.extend([
        "--sd",
        source_subjects_dir
    ])
    if num_iters is not None:
        cargs.extend([
            "--niters",
            str(num_iters)
        ])
    if num_threads is not None:
        cargs.extend([
            "--nthreads",
            str(num_threads)
        ])
    if exclude_file is not None:
        cargs.extend([
            "--x",
            execution.input_file(exclude_file)
        ])
    if exclude_subject is not None:
        cargs.extend([
            "--xs",
            exclude_subject
        ])
    if symmetric_atlas:
        cargs.append("--sym")
    if color_table is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(color_table)
        ])
    if no_submit:
        cargs.append("--no-submit")
    if mail_flag:
        cargs.append("--pb-m")
    if no_strict:
        cargs.append("--no-strict")
    if gcareg_iters:
        cargs.append("--gcareg-iters")
    if prep_only:
        cargs.append("--prep-only")
    if nu10_flag:
        cargs.append("--nu10")
    if nu12_flag:
        cargs.append("--nu12")
    if no_emreg:
        cargs.append("--no-emreg")
    ret = GcatrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GCATRAIN_METADATA",
    "GcatrainOutputs",
    "gcatrain",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISOLATE_LABELS_KEEPORIGVAL_CSH_METADATA = Metadata(
    id="df797eee81eb441fe4aa69105caafa1c949467cd.boutiques",
    name="isolate_labels_keeporigval.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsolateLabelsKeeporigvalCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `isolate_labels_keeporigval_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_files: OutputPathType
    """Output binary label file(s)"""


def isolate_labels_keeporigval_csh(
    vol: InputPathType,
    outprefix: str,
    label: str | None = None,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> IsolateLabelsKeeporigvalCshOutputs:
    """
    Separates out a particular or all labels into individual binary files keeping
    the original label values for subsequent shape analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vol: Label volume to be analyzed.
        outprefix: Prefix for output binary label file(s).
        label: The particular label to be analyzed. By default, it is ALL\
            labels in the volume.
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsolateLabelsKeeporigvalCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISOLATE_LABELS_KEEPORIGVAL_CSH_METADATA)
    cargs = []
    cargs.append("isolate_labels_keeporigval.csh")
    cargs.extend([
        "--vol",
        execution.input_file(vol)
    ])
    cargs.extend([
        "--outprefix",
        outprefix
    ])
    if label is not None:
        cargs.extend([
            "--l",
            label
        ])
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = IsolateLabelsKeeporigvalCshOutputs(
        root=execution.output_file("."),
        output_label_files=execution.output_file(outprefix + "_label*.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISOLATE_LABELS_KEEPORIGVAL_CSH_METADATA",
    "IsolateLabelsKeeporigvalCshOutputs",
    "isolate_labels_keeporigval_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POLYORDER_METADATA = Metadata(
    id="3c8b24e1442e41d2305967e2496acc7a689b044a.boutiques",
    name="polyorder",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PolyorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `polyorder(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def polyorder(
    ntp: float,
    tr: float,
    cutoff: float,
    runner: Runner | None = None,
) -> PolyorderOutputs:
    """
    Computes the order of polynomial regressors needed to achieve a highpass filter
    with the given cutoff frequency.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        ntp: Number of time points (i.e., number of TRs).
        tr: TR in seconds.
        cutoff: Cutoff frequency in Hz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PolyorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POLYORDER_METADATA)
    cargs = []
    cargs.append("polyorder")
    cargs.extend([
        "--ntp",
        str(ntp)
    ])
    cargs.extend([
        "--TR",
        str(tr)
    ])
    cargs.extend([
        "--cutoff",
        str(cutoff)
    ])
    ret = PolyorderOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POLYORDER_METADATA",
    "PolyorderOutputs",
    "polyorder",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_TWOCLASS_METADATA = Metadata(
    id="427d89171227769404d91a8705196b0fd4c94fb1.boutiques",
    name="mri_twoclass",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriTwoclassOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_twoclass(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_volume: OutputPathType
    """Output volume storing the results"""


def mri_twoclass(
    segmentation_volume: InputPathType,
    output_subject: str,
    output_volume: InputPathType,
    c1_subjects: list[str],
    c2_subjects: list[str],
    f_threshold: float | None = None,
    bonferroni_correction: bool = False,
    runner: Runner | None = None,
) -> MriTwoclassOutputs:
    """
    Compute cross-subject statistics of two sets of labels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        segmentation_volume: Input segmentation volume.
        output_subject: Output subject name.
        output_volume: Output volume.
        c1_subjects: List of subjects from class 1.
        c2_subjects: List of subjects from class 2.
        f_threshold: Specify F threshold.
        bonferroni_correction: Perform Bonferroni correction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriTwoclassOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_TWOCLASS_METADATA)
    cargs = []
    cargs.append("mri_twoclass")
    cargs.append(execution.input_file(segmentation_volume))
    cargs.append(output_subject)
    cargs.append(execution.input_file(output_volume))
    cargs.extend(c1_subjects)
    cargs.append(":")
    cargs.extend(c2_subjects)
    if f_threshold is not None:
        cargs.extend([
            "-t",
            str(f_threshold)
        ])
    if bonferroni_correction:
        cargs.append("-b")
    ret = MriTwoclassOutputs(
        root=execution.output_file("."),
        result_volume=execution.output_file(pathlib.Path(output_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_TWOCLASS_METADATA",
    "MriTwoclassOutputs",
    "mri_twoclass",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_TO_ROIS_METADATA = Metadata(
    id="53ffc190f09f435ce8a8a69ab0341699da3030a0.boutiques",
    name="border-to-rois",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BorderToRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_to_rois(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def border_to_rois(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
    opt_inverse: bool = False,
    opt_include_border: bool = False,
    runner: Runner | None = None,
) -> BorderToRoisOutputs:
    """
    Make metric rois from borders.
    
    By default, draws ROIs inside all borders in the border file, as separate
    metric columns.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
        opt_inverse: use inverse selection (outside border).
        opt_include_border: include vertices the border is closest to.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToRoisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_TO_ROIS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-to-rois")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(border_file))
    cargs.append(metric_out)
    if opt_border_name is not None:
        cargs.extend([
            "-border",
            opt_border_name
        ])
    if opt_inverse:
        cargs.append("-inverse")
    if opt_include_border:
        cargs.append("-include-border")
    ret = BorderToRoisOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_TO_ROIS_METADATA",
    "BorderToRoisOutputs",
    "border_to_rois",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NWARP_ADJUST_METADATA = Metadata(
    id="0c3ecbaf201c4034c9ca75f6bc8b7c5f5190cfaf.boutiques",
    name="3dNwarpAdjust",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNwarpAdjustOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_nwarp_adjust(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType | None
    """Output mean dataset BRIK file"""
    output_head: OutputPathType | None
    """Output mean dataset HEAD file"""


def v_3d_nwarp_adjust(
    input_warps: list[InputPathType],
    source_datasets: list[InputPathType] | None = None,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dNwarpAdjustOutputs:
    """
    Program to adjust 3D warp datasets by composing them with the inverse of their
    average, optionally warping input datasets and generating an output mean
    dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_warps: List of input 3D warp datasets (at least 5).
        source_datasets: List of input 3D datasets to be warped by the adjusted\
            warp datasets. There must be exactly as many of these datasets as there\
            are input warps.
        output_prefix: Prefix for the output mean dataset (only needed if the\
            '-source' option is also given).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNwarpAdjustOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NWARP_ADJUST_METADATA)
    cargs = []
    cargs.append("3dNwarpAdjust")
    cargs.extend([
        "-nwarp",
        *[execution.input_file(f) for f in input_warps]
    ])
    if source_datasets is not None:
        cargs.extend([
            "-source",
            *[execution.input_file(f) for f in source_datasets]
        ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    ret = V3dNwarpAdjustOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file(output_prefix + "+tlrc.BRIK") if (output_prefix is not None) else None,
        output_head=execution.output_file(output_prefix + "+tlrc.HEAD") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNwarpAdjustOutputs",
    "V_3D_NWARP_ADJUST_METADATA",
    "v_3d_nwarp_adjust",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_GRADIENT_METADATA = Metadata(
    id="8af5e6bf60b53a0f383725072c1fa1ba36511752.boutiques",
    name="volume-gradient",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeGradientPresmooth:
    """
    smooth the volume before computing the gradient.
    """
    kernel: float
    """the size of the gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


class VolumeGradientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_gradient(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output gradient magnitude volume"""
    opt_vectors_vector_volume_out: OutputPathType | None
    """output vectors: the vectors as a volume file"""


def volume_gradient(
    volume_in: InputPathType,
    volume_out: str,
    presmooth: VolumeGradientPresmooth | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_vectors_vector_volume_out: str | None = None,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeGradientOutputs:
    """
    Gradient of a volume file.
    
    Computes the gradient of the volume by doing linear regressions for each
    voxel, considering only its face neighbors unless too few face neighbors
    exist. The gradient vector is constructed from the partial derivatives of
    the resulting linear function, and the magnitude of this vector is the
    output. If specified, the volume vector output is arranged with the x, y,
    and z components from a subvolume as consecutive subvolumes.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        volume_out: the output gradient magnitude volume.
        presmooth: smooth the volume before computing the gradient.
        opt_roi_roi_volume: select a region of interest to take the gradient\
            of: the region to take the gradient within.
        opt_vectors_vector_volume_out: output vectors: the vectors as a volume\
            file.
        opt_subvolume_subvol: select a single subvolume to take the gradient\
            of: the subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeGradientOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_GRADIENT_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-gradient")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_out)
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    if opt_roi_roi_volume is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_volume)
        ])
    if opt_vectors_vector_volume_out is not None:
        cargs.extend([
            "-vectors",
            opt_vectors_vector_volume_out
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    ret = VolumeGradientOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
        opt_vectors_vector_volume_out=execution.output_file(opt_vectors_vector_volume_out) if (opt_vectors_vector_volume_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_GRADIENT_METADATA",
    "VolumeGradientOutputs",
    "VolumeGradientPresmooth",
    "volume_gradient",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GROUPSTATSDIFF_METADATA = Metadata(
    id="474a0a73a03ccd5e8c25186fbb8a8f0ccde75dd7.boutiques",
    name="groupstatsdiff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GroupstatsdiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `groupstatsdiff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def groupstatsdiff(
    group1_dir: str,
    group2_dir: str,
    output_dir: str,
    no_maps: bool = False,
    osgm: bool = False,
    no_common: bool = False,
    allow_subj_diff: bool = False,
    no_area: bool = False,
    no_volume: bool = False,
    no_ba: bool = False,
    no_aparcstats: bool = False,
    no_asegstats: bool = False,
    no_wparcstats: bool = False,
    no_stats: bool = False,
    no_prune: bool = False,
    fwhm_value: float | None = None,
    subjects_dir1: str | None = None,
    subjects_dir2: str | None = None,
    no_dice: bool = False,
    dice_ctab: str | None = None,
    runner: Runner | None = None,
) -> GroupstatsdiffOutputs:
    """
    Evaluate the differences between two groupstats outputs from recon-all analyses
    in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        group1_dir: Output folder from groupstats for group 1.
        group2_dir: Output folder from groupstats for group 2.
        output_dir: Output folder for the difference analysis.
        no_maps: Only analyze ROI data, no maps.
        osgm: Use OSGM instead of native FSGD.
        no_common: Do not select common segments when running stattablediff.
        allow_subj_diff: Allow list of subjects to be different between the two\
            analyses.
        no_area: Do not compute area differences.
        no_volume: Do not compute volume differences.
        no_ba: Do not compute differences for BA labels.
        no_aparcstats: Do not do aparcstats.
        no_asegstats: Do not do asegstats.
        no_wparcstats: Do not do wmparcstats.
        no_stats: Do not do any ROI stats.
        no_prune: Do not prune when running mri_glmfit.
        fwhm_value: Override the FWHM from group analysis.
        subjects_dir1: Subjects directory 1 for computing dice (default is\
            parent dir of groupdir).
        subjects_dir2: Subjects directory 2 for computing dice (default is\
            parent dir of groupdir).
        no_dice: Do not compute dice.
        dice_ctab: CTAB to use for dice computation (default is\
            /usr/local/freesurfer/ASegStatsLUT.txt).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GroupstatsdiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GROUPSTATSDIFF_METADATA)
    cargs = []
    cargs.append("groupstatsdiff")
    cargs.extend([
        "-g1",
        "-" + group1_dir
    ])
    cargs.extend([
        "-g2",
        "-" + group2_dir
    ])
    cargs.extend([
        "-o",
        "-" + output_dir
    ])
    if no_maps:
        cargs.append("--no-maps")
    if osgm:
        cargs.append("--osgm")
    if no_common:
        cargs.append("--no-common")
    if allow_subj_diff:
        cargs.append("--allow-subj-diff")
    if no_area:
        cargs.append("--no-area")
    if no_volume:
        cargs.append("--no-volume")
    if no_ba:
        cargs.append("--no-ba")
    if no_aparcstats:
        cargs.append("--no-aparcstats")
    if no_asegstats:
        cargs.append("--no-asegstats")
    if no_wparcstats:
        cargs.append("--no-wparcstats")
    if no_stats:
        cargs.append("--no-stats")
    if no_prune:
        cargs.append("--no-prune")
    if fwhm_value is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm_value)
        ])
    if subjects_dir1 is not None:
        cargs.extend([
            "--sd1",
            subjects_dir1
        ])
    if subjects_dir2 is not None:
        cargs.extend([
            "--sd2",
            subjects_dir2
        ])
    if no_dice:
        cargs.append("--no-dice")
    if dice_ctab is not None:
        cargs.extend([
            "--dice-ctab",
            dice_ctab
        ])
    ret = GroupstatsdiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GROUPSTATSDIFF_METADATA",
    "GroupstatsdiffOutputs",
    "groupstatsdiff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MVM_GRIDCONV_PY_METADATA = Metadata(
    id="8ae9f4629987e35362a12cb081ce643576e4a5c4.boutiques",
    name="fat_mvm_gridconv.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMvmGridconvPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mvm_gridconv_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_grid_files: OutputPathType
    """Output converted grid files, with '_MOD.grid' postfix or custom output
    name provided in the list file."""


def fat_mvm_gridconv_py(
    matrix_files: str | None = None,
    list_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> FatMvmGridconvPyOutputs:
    """
    Preprocess 'old school' *.grid files for statistical modeling using 3dMVM.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        matrix_files: Provide the set of matrix (*.grid) files as a searchable\
            path. This can be a globbable entry in quotes containing wildcard\
            characters.
        list_file: Provide the matrix (*.grid) files by explicit path in a text\
            file. The LIST text file must contain at least one column (path to\
            subject matrix file) with an optional second column (output file\
            names). If no second column is given, the default '_MOD.grid' postfix\
            is applied.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMvmGridconvPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MVM_GRIDCONV_PY_METADATA)
    cargs = []
    cargs.append("fat_mvm_gridconv.py")
    if matrix_files is not None:
        cargs.extend([
            "-m",
            matrix_files
        ])
    if list_file is not None:
        cargs.extend([
            "-l",
            execution.input_file(list_file)
        ])
    ret = FatMvmGridconvPyOutputs(
        root=execution.output_file("."),
        converted_grid_files=execution.output_file("*_MOD.grid"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MVM_GRIDCONV_PY_METADATA",
    "FatMvmGridconvPyOutputs",
    "fat_mvm_gridconv_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANATOMICAL_AVERAGE_METADATA = Metadata(
    id="247f0a40aa16f444290b87939a981d90386a5a1a.boutiques",
    name="AnatomicalAverage",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class AnatomicalAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `anatomical_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    avg_output: OutputPathType
    """Averaged anatomical image"""


def anatomical_average(
    output_basename: str,
    input_images: list[InputPathType],
    standard_image: InputPathType | None = None,
    standard_brain_mask: InputPathType | None = None,
    no_crop_flag: bool = False,
    work_dir: str | None = None,
    brainsize: float | None = None,
    noclean_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> AnatomicalAverageOutputs:
    """
    Tool to create an anatomical average of input brain images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        output_basename: Output basename.
        input_images: List of input images.
        standard_image: Standard image (default is MNI152_T1_2mm).
        standard_brain_mask: Standard brain mask (default is\
            MNI152_T1_2mm_brain_mask_dil).
        no_crop_flag: Do not crop images.
        work_dir: Local, temporary working directory (to be cleaned up - i.e.\
            deleted).
        brainsize: Specify brainsize in mm for internal ROI (via robustfov).
        noclean_flag: Do not run the cleanup.
        verbose_flag: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnatomicalAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANATOMICAL_AVERAGE_METADATA)
    cargs = []
    cargs.append("AnatomicalAverage")
    cargs.extend([
        "-o",
        output_basename
    ])
    cargs.extend([execution.input_file(f) for f in input_images])
    if standard_image is not None:
        cargs.extend([
            "-s",
            execution.input_file(standard_image)
        ])
    if standard_brain_mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(standard_brain_mask)
        ])
    if no_crop_flag:
        cargs.append("-n")
    if work_dir is not None:
        cargs.extend([
            "-w",
            work_dir
        ])
    if brainsize is not None:
        cargs.extend([
            "-b",
            str(brainsize)
        ])
    if noclean_flag:
        cargs.append("--noclean")
    if verbose_flag:
        cargs.append("-v")
    ret = AnatomicalAverageOutputs(
        root=execution.output_file("."),
        avg_output=execution.output_file(output_basename + "_avg.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANATOMICAL_AVERAGE_METADATA",
    "AnatomicalAverageOutputs",
    "anatomical_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_1_PREPROC_METADATA = Metadata(
    id="4f04562a7b05be2549dde3df1b1c7f328fc44461.boutiques",
    name="tbss_1_preproc",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Tbss1PreprocOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_1_preproc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_1_preproc(
    images: list[InputPathType],
    runner: Runner | None = None,
) -> Tbss1PreprocOutputs:
    """
    TBSS (Tract-Based Spatial Statistics) - Step 1: Preprocessing.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        images: List of input images (e.g. subj1_FA.nii.gz subj2_FA.nii.gz ...).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tbss1PreprocOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_1_PREPROC_METADATA)
    cargs = []
    cargs.append("tbss_1_preproc")
    cargs.extend([execution.input_file(f) for f in images])
    ret = Tbss1PreprocOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_1_PREPROC_METADATA",
    "Tbss1PreprocOutputs",
    "tbss_1_preproc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DWI2MASK_METADATA = Metadata(
    id="e651be545db3db1ef7ebcf19117cf1ddd7e6b8f2.boutiques",
    name="dwi2mask",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Dwi2maskFslgrad:
    """
    Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


@dataclasses.dataclass
class Dwi2maskConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Dwi2maskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dwi2mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output whole-brain mask image"""


def dwi2mask(
    input_: InputPathType,
    output: str,
    clean_scale: int | None = None,
    grad: InputPathType | None = None,
    fslgrad: Dwi2maskFslgrad | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Dwi2maskConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Dwi2maskOutputs:
    """
    Generates a whole brain mask from a DWI image.
    
    All diffusion weighted and b=0 volumes are used to obtain a mask that
    includes both brain tissue and CSF.
    
    In a second step peninsula-like extensions, where the peninsula itself is
    wider than the bridge connecting it to the mask, are removed. This may help
    removing artefacts and non-brain parts, e.g. eyes, from the mask.
    
    References:
    
    Dhollander T, Raffelt D, Connelly A. Unsupervised 3-tissue response function
    estimation from single-shell or multi-shell diffusion MR data without a
    co-registered T1 image. ISMRM Workshop on Breaking the Barriers of Diffusion
    MRI, 2016, 5.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input DWI image containing volumes that are both diffusion\
            weighted and b=0.
        output: the output whole-brain mask image.
        clean_scale: the maximum scale used to cut bridges. A certain maximum\
            scale cuts bridges up to a width (in voxels) of 2x the provided scale.\
            Setting this to 0 disables the mask cleaning step. (Default: 2).
        grad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in a text file. This should be supplied as a 4xN text file\
            with each line is in the format [ X Y Z b ], where [ X Y Z ] describe\
            the direction of the applied gradient, and b gives the b-value in units\
            of s/mm^2. If a diffusion gradient scheme is present in the input image\
            header, the data provided with this option will be instead used.
        fslgrad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in FSL bvecs/bvals format files. If a diffusion gradient\
            scheme is present in the input image header, the data provided with\
            this option will be instead used.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dwi2maskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DWI2MASK_METADATA)
    cargs = []
    cargs.append("dwi2mask")
    if clean_scale is not None:
        cargs.extend([
            "-clean_scale",
            str(clean_scale)
        ])
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(output)
    ret = Dwi2maskOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DWI2MASK_METADATA",
    "Dwi2maskConfig",
    "Dwi2maskFslgrad",
    "Dwi2maskOutputs",
    "dwi2mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSREAD_ANNOT_METADATA = Metadata(
    id="1aee44cf7efa00cb2630f7f3d7fb84af69eadb4f.boutiques",
    name="FSread_annot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FsreadAnnotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsread_annot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_col_1d: OutputPathType
    """Output 4-column 1D color file."""
    out_roi_1d: OutputPathType
    """Output 5-column 1D ROI file."""
    out_niml_dset: OutputPathType
    """Output niml formatted label dataset."""
    out_cmap_1d: OutputPathType
    """Output 4-column 1D color map file."""


def fsread_annot(
    infile: InputPathType,
    hemi: str | None = None,
    fscmap: InputPathType | None = None,
    fscmap_range: list[float] | None = None,
    fsversion: str | None = None,
    col_1d: str | None = None,
    roi_1d: str | None = None,
    cmap_1d: str | None = None,
    show_fscmap: bool = False,
    dset: str | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> FsreadAnnotOutputs:
    """
    Reads a FreeSurfer annotation file and outputs an equivalent ROI file and/or a
    colormap file for use with SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Binary formatted FreeSurfer annotation file.
        hemi: Specify hemisphere. HEMI is one of lh or rh. Program guesses by\
            default.
        fscmap: Get the colormap from the Freesurfer colormap file CMAPFILE.\
            Colormaps inside the ANNOTFILE would be ignored.
        fscmap_range: CMAPFILE contains multiple types of labels. The\
            annotation values in ANNOTFILE can map to multiple labels if you do not\
            restrict the range with iMin and iMax.
        fsversion: VER is the annotation file vintage. Choose from 2009 or\
            2005.
        col_1d: Write a 4-column 1D color file.
        roi_1d: Write a 5-column 1D roi file.
        cmap_1d: Write a 4-column 1D color map file.
        show_fscmap: Show the info of the colormap in the ANNOT file.
        dset: Write the annotation and colormap as a niml formatted Label Dset.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsreadAnnotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSREAD_ANNOT_METADATA)
    cargs = []
    cargs.append("FSread_annot")
    cargs.extend([
        "-input",
        "-" + execution.input_file(infile)
    ])
    if hemi is not None:
        cargs.extend([
            "-hemi",
            hemi
        ])
    if fscmap is not None:
        cargs.extend([
            "-FScmap",
            execution.input_file(fscmap)
        ])
    if fscmap_range is not None:
        cargs.extend([
            "-FScmaprange",
            *map(str, fscmap_range)
        ])
    if fsversion is not None:
        cargs.extend([
            "-FSversion",
            fsversion
        ])
    if col_1d is not None:
        cargs.extend([
            "-col_1D",
            col_1d
        ])
    if roi_1d is not None:
        cargs.extend([
            "-roi_1D",
            roi_1d
        ])
    if cmap_1d is not None:
        cargs.extend([
            "-cmap_1D",
            cmap_1d
        ])
    if show_fscmap:
        cargs.append("-show_FScmap")
    if dset is not None:
        cargs.extend([
            "-dset",
            dset
        ])
    if help_:
        cargs.append("-help")
    ret = FsreadAnnotOutputs(
        root=execution.output_file("."),
        out_col_1d=execution.output_file("annot.1D.col"),
        out_roi_1d=execution.output_file("annot.1D.roi"),
        out_niml_dset=execution.output_file("annot.niml.dset"),
        out_cmap_1d=execution.output_file("annot.1D.cmap"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSREAD_ANNOT_METADATA",
    "FsreadAnnotOutputs",
    "fsread_annot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DGRAYPLOT_METADATA = Metadata(
    id="9f1dfb91ea2888caae64e3a7a65f59bb59e4f314.boutiques",
    name="1dgrayplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dgrayplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dgrayplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1dgrayplot(
    tsfile: InputPathType,
    install: bool = False,
    ignore: float | None = None,
    flip: bool = False,
    sep: bool = False,
    use: float | None = None,
    ps: bool = False,
    runner: Runner | None = None,
) -> V1dgrayplotOutputs:
    """
    Graphs the columns of a *.1D type time series file to the screen in grayscale.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        tsfile: Input time series file (*.1D format).
        install: Install a new X11 colormap (for X11 PseudoColor).
        ignore: Skip first 'nn' rows in the input file [default = 0].
        flip: Plot x and y axes interchanged [default: data columns plotted\
            DOWN the screen].
        sep: Separate scales for each column.
        use: Plot 'mm' points [default: all of them].
        ps: Don't draw plot in a window; write it to stdout in PostScript\
            format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dgrayplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DGRAYPLOT_METADATA)
    cargs = []
    cargs.append("1dgrayplot")
    cargs.append(execution.input_file(tsfile))
    if install:
        cargs.append("-install")
    if ignore is not None:
        cargs.extend([
            "-ignore",
            str(ignore)
        ])
    if flip:
        cargs.append("-flip")
    if sep:
        cargs.append("-sep")
    if use is not None:
        cargs.extend([
            "-use",
            str(use)
        ])
    if ps:
        cargs.append("-ps")
    ret = V1dgrayplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dgrayplotOutputs",
    "V_1DGRAYPLOT_METADATA",
    "v_1dgrayplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LSS_METADATA = Metadata(
    id="d793e92300ed18c69c7d31223293711fdbbfaaf7.boutiques",
    name="3dLSS",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLssOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lss(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset containing the LSS estimates of the beta weights for the
    '-stim_times_IM' stimuli."""
    save1_d_output: OutputPathType
    """Estimator vectors saved in a 1D formatted file."""


def v_3d_lss(
    runner: Runner | None = None,
) -> V3dLssOutputs:
    """
    Least-Squares-Sum (LSS) estimation tool from a -stim_times_IM matrix for
    multivoxel pattern classification analyses.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLssOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LSS_METADATA)
    cargs = []
    cargs.append("3dLSS")
    cargs.append("[OPTIONS]")
    ret = V3dLssOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("LSSout+orig.HEAD"),
        save1_d_output=execution.output_file("[SAVE1D]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLssOutputs",
    "V_3D_LSS_METADATA",
    "v_3d_lss",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TRANSFORM_METADATA = Metadata(
    id="8c13e0715d0d51bf0467c4fca8ecf1a12c72c46b.boutiques",
    name="mris_transform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_output_surface: OutputPathType
    """Transformed output surface file."""


def mris_transform(
    input_surface: InputPathType,
    transform: InputPathType,
    output_surface: str,
    trx_src: InputPathType | None = None,
    trx_dst: InputPathType | None = None,
    is_inverse: bool = False,
    runner: Runner | None = None,
) -> MrisTransformOutputs:
    """
    A tool to transform surfaces from one space to another using image transforms.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file, e.g., lh.pial.
        transform: Image-to-image transform file, e.g., LTA or M3Z.
        output_surface: Output surface file, e.g., lh.out.pial.
        trx_src: Specify the source geometry if the transform was created by\
            MNI/mritotal or FSL/flirt.
        trx_dst: Specify the destination geometry if the transform does not\
            include this information or the path in the M3Z is invalid.
        is_inverse: Use this option when using a transform from destination to\
            source space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TRANSFORM_METADATA)
    cargs = []
    cargs.append("mris_transform")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(transform))
    cargs.append(output_surface)
    if trx_src is not None:
        cargs.extend([
            "--trx-src",
            execution.input_file(trx_src)
        ])
    if trx_dst is not None:
        cargs.extend([
            "--trx-dst",
            execution.input_file(trx_dst)
        ])
    if is_inverse:
        cargs.append("--is-inverse")
    ret = MrisTransformOutputs(
        root=execution.output_file("."),
        transformed_output_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TRANSFORM_METADATA",
    "MrisTransformOutputs",
    "mris_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IREPIFITVOL_GLNX64_METADATA = Metadata(
    id="e1b3c71003d88eeb91c6bc522cbeb9c8dec5641d.boutiques",
    name="irepifitvol.glnx64",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IrepifitvolGlnx64Outputs(typing.NamedTuple):
    """
    Output object returned when calling `irepifitvol_glnx64(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """The fitted volume output from the irepifitvol process."""


def irepifitvol_glnx64(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> IrepifitvolGlnx64Outputs:
    """
    This tool is a part of the FreeSurfer toolkit, designed for certain volume
    fitting tasks.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: The input volume file to be processed.
        output_file: The path to save the output volume file after fitting.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IrepifitvolGlnx64Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IREPIFITVOL_GLNX64_METADATA)
    cargs = []
    cargs.append("irepifitvol")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = IrepifitvolGlnx64Outputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IREPIFITVOL_GLNX64_METADATA",
    "IrepifitvolGlnx64Outputs",
    "irepifitvol_glnx64",
]
